@@ -1,16 +1,12 @@
 #!/usr/bin/perl -sw
 ##
-##
-##
-## Copyright (c) 2001, Vipul Ved Prakash.  All rights reserved.
+## Copyright (c) 1998-2018, Vipul Ved Prakash.  All rights reserved.
 ## This code is free software; you can redistribute it and/or modify
 ## it under the same terms as Perl itself.
-##
-## $Id: devurandom.pm,v 1.2 2001/06/22 18:16:29 vipul Exp $
 
 package Crypt::Random::Provider::devurandom; 
 use strict;
-use lib qw(/home/vipul/PERL/crypto/random/lib);
+use lib qw(lib);
 use Crypt::Random::Provider::File;
 use vars qw(@ISA);
 @ISA = qw(Crypt::Random::Provider::File);
